@@ -1,6 +1,8 @@
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
-from .utils import (check_columns, extract_numeric_cols,
+from .utils import (check_columns,
+                    extract_numeric_cols,
+                    check_dictionary,
                     check_dataframe,
                     column_mean,
                     check_numeric)
@@ -175,6 +177,63 @@ class NaFiller(BaseEstimator, TransformerMixin):
                 return X
 
 
+class ConstantValueFiller(BaseEstimator, TransformerMixin):
+    def __init__(self, value, limit=None):
+        """
+        Performs Missing value imputation using a constant value or dictionary,
+        this dictionary has the column name as key and the value to use to fill as value
+        :param value:  dictionary which maps column name to value or interger or string
+        :param limit:int, (default = None) the maximum number of missing value per column to be filled,
+                if None, all missing values would be filled
+
+        Usage
+        >>> import pandas as pd
+        >>> import numpy as np
+        >>> df2 = pd.DataFrame({'A':[np.nan,2,3,4,5,8],'B':[2,np.nan,np.nan,np.nan,10,9],'C':[1,3,5, np.nan, np.nan,7]})
+        >>> cvf = ConstantValueFiller(value={'A':100, 'B':200,'C':300}, limit=1)
+        >>> vx = cvf.transform(X=df2)
+        >>> print(vx)
+               A      B      C
+        0  100.0    2.0    1.0
+        1    2.0  200.0    3.0
+        2    3.0    NaN    5.0
+        3    4.0    NaN  300.0
+        4    5.0   10.0    NaN
+        5    8.0    9.0    7.0
+
+        >>> cvf = ConstantValueFiller(value=200, limit=None)
+        >>> vx = cvf.transform(X=df2)
+        >>> print(vx)
+               A      B      C
+        0  200.0    2.0    1.0
+        1    2.0  200.0    3.0
+        2    3.0  200.0    5.0
+        3    4.0  200.0  200.0
+        4    5.0   10.0  200.0
+        5    8.0    9.0    7.0
+        """
+        self.value = value
+        self.limit = limit
+        assert isinstance(value, dict) or value is not None, "fill_dict is expected to be a dictionary"
+        assert isinstance(limit, int) or limit is None
+
+    def fit(self, X, y=None):
+        return self
+
+    def transform(self, X, y=None):
+        X = X.copy()
+
+        if check_dataframe(df=X):
+            if isinstance(self.value, int) or isinstance(self.value, float) or isinstance(self.value, str):
+                X.fillna(value=self.value, inplace=True, limit=self.limit)
+                return X
+            if check_dictionary(df=X, column_dict=self.value):
+                X.fillna(value=self.value, inplace=True, limit=self.limit)
+                return X
+
+        return X
+
+
 class ColumnRename(BaseEstimator, TransformerMixin):
     def __init__(self, rename_dictionary):
         """
@@ -214,6 +273,55 @@ class ColumnRename(BaseEstimator, TransformerMixin):
         return X
 
 
+class NADropper(BaseEstimator, TransformerMixin):
+    def __init__(self, axis=1,how='all',thresh=None):
+        """
+        Transformer for dropping columns with missing value.
+        :param axis: 0 or 'index', drops rows which contain missing value, 1 or 'columns' drops columns which contain missing value.
+        :param how: str, 'any','all'. drop row or column if any NA is present, drop row or column if all values are missing.
+        :param thresh: int, require that many non NA values
+
+        Usage
+        >>> import pandas as pd
+        >>> import numpy as np
+        >>> df3 = pd.DataFrame({'A':[np.nan,2,3,4,5],'B':[2,np.nan,np.nan,np.nan,10],
+            ... 'C':['dog','cat', 'sheep','dog','cat'],'D':['male','male','male','female','female'],
+            ... 'E':[True,True,False,True,True]})
+        >>> nadropper = NADropper(axis='columns', how='any')
+        >>> droped2 = nadropper.transform(X=df2)
+               C       D      E
+        0    dog    male   True
+        1    cat    male   True
+        2  sheep    male  False
+        3    dog  female   True
+        4    cat  female   True
+
+        """
+        self.axis = axis
+        self.how = how
+        self.thresh = thresh
+        assert isinstance(thresh,int) or thresh is None,"thresh is expected to be an integer"
+        assert how in ['any','all']
+        assert axis in [0,1,'index','columns'],""
+
+    def fit(self, X, y=None):
+        return self
+
+    def transform(self, X, y=None):
+        if check_dataframe(df=X):
+            X = X.copy()
+            X.dropna(axis=self.axis, how=self.how, thresh=self.thresh, inplace=True)
+
+        return X
+
+
+# class
+
+
+
+
+
+
 
 
 
